@@ -1,26 +1,27 @@
-/*  libhdate
- *  Copyright  2004-2005  Yaacov Zamir <kzamir@walla.co.il>
+/*  libhdate - Hebrew calendar library
+ *
+ *  Copyright (C) 1984-2003 Amos Shapir, 2004-2007  Yaacov Zamir <kzamir@walla.co.il>
  *  
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/*
- * See Amos Shapir hdate_README file attached for 
- * Copyright notice for functions based on Amos's code
- */
- 
+/** @file hdate.h
+    @brief libhdate C language header.
+    
+    libhdate - Hebrew calendar library, the C language header file.
+*/
+
 #ifndef __HDATE_H__
 #define __HDATE_H__
 
@@ -29,28 +30,28 @@ extern "C"
 {
 #endif
 
-/** @def HDATA_DIASPORA_FLAG
+/** @def HDATE_DIASPORA_FLAG
   @brief use diaspora dates and holydays flag
 */
-#define HDATA_DIASPORA_FLAG -1
+#define HDATE_DIASPORA_FLAG -1
 	
-/** @def HDATA_ISRAEL_FLAG
+/** @def HDATE_ISRAEL_FLAG
   @brief use israel dates and holydays flag
 */
-#define HDATA_ISRAEL_FLAG 0
+#define HDATE_ISRAEL_FLAG 0
 	
-/** @def HDATA_SHORT_FLAG
+/** @def HDATE_SHORT_FLAG
   @brief use short strings flag
 */
-#define HDATA_SHORT_FLAG -1
+#define HDATE_SHORT_FLAG -1
 	
-/** @def HDATA_LONG_FLAG
+/** @def HDATE_LONG_FLAG
   @brief use long strings flag
 */
-#define HDATA_LONG_FLAG 0
-
-/** Base structore for hebrew dates
+#define HDATE_LONG_FLAG 0
 
+/** @struct hdate_struct
+  @brief libhdate Hebrew date struct
 */
 typedef struct
 {
@@ -342,15 +343,23 @@ hdate_get_day_of_year (int day, int month, int year);
 
 /**
  @brief utc sun times for altitude at a gregorian date
-  
- @parm day this day of month
- @parm month this month
- @parm year this year
- @parm longitude longitude to use in calculations
- @parm latitude latitude to use in calculations
- @parm deg degrees of sun's altitude (0 -  Zenith .. 90 - Horizon)
- @parm sunrise return the utc sunrise in minutes
- @parm sunset return the utc sunset in minutes
+
+ Returns the sunset and sunrise times in minutes from 00:00 (utc time)
+ if sun altitude in sunrise is deg degries.
+ This function only works for altitudes sun realy is.
+ If the sun never get to this altitude, the returned sunset and sunrise values 
+ will be negative. This can happen in low altitude when latitude is 
+ nearing the pols in winter times, the sun never goes very high in 
+ the sky there.
+
+ @param day this day of month
+ @param month this month
+ @param year this year
+ @param longitude longitude to use in calculations
+ @param latitude latitude to use in calculations
+ @param deg degrees of sun's altitude (0 -  Zenith .. 90 - Horizon)
+ @param sunrise return the utc sunrise in minutes
+ @param sunset return the utc sunset in minutes
 */
 void
 hdate_get_utc_sun_time_deg (int day, int month, int year, 
@@ -364,7 +373,7 @@ hdate_get_utc_sun_time_deg (int day, int month, int year,
  @param year this year
  @param longitude longitude to use in calculations
 	degrees, negative values are east
-  @param latitude latitude to use in calculations
+ @param latitude latitude to use in calculations
 	degrees, negative values are south
  @param sunrise return the utc sunrise in minutes after midnight (00:00)
  @param sunset return the utc sunset in minutes after midnight (00:00)
@@ -376,19 +385,19 @@ hdate_get_utc_sun_time (int day, int month, int year,
 /**
  @brief utc sunrise/set time for a gregorian date
   
- @parm day this day of month
- @parm month this month
- @parm year this year
- @parm longitude longitude to use in calculations
- @parm latitude latitude to use in calculations
- @parm sun_hour return the length of shaa zaminit in minutes
- @parm first_light return the utc alut ha-shachar in minutes
- @parm talit return the utc tphilin and talit in minutes
- @parm sunrise return the utc sunrise in minutes
- @parm midday return the utc midday in minutes
- @parm sunset return the utc sunset in minutes
- @parm first_stars return the utc tzeit hacochavim in minutes
- @parm three_stars return the utc shlosha cochavim in minutes
+ @param day this day of month
+ @param month this month
+ @param year this year
+ @param longitude longitude to use in calculations
+ @param latitude latitude to use in calculations
+ @param sun_hour return the length of shaa zaminit in minutes
+ @param first_light return the utc alut ha-shachar in minutes
+ @param talit return the utc tphilin and talit in minutes
+ @param sunrise return the utc sunrise in minutes
+ @param midday return the utc midday in minutes
+ @param sunset return the utc sunset in minutes
+ @param first_stars return the utc tzeit hacochavim in minutes
+ @param three_stars return the utc shlosha cochavim in minutes
 */
 void
 hdate_get_utc_sun_time_full (int day, int month, int year, double latitude, double longitude, 
